@@ -1,7 +1,6 @@
 #################################################################################
 ##
-##   R package rugarch by Alexios Ghalanos Copyright (C) 2008, 2009, 2010, 2011, 
-##	 2012
+##   R package rugarch by Alexios Ghalanos Copyright (C) 2008-2013.
 ##   This file is part of the R package rugarch.
 ##
 ##   The R package rugarch is free software: you can redistribute it and/or modify
@@ -53,9 +52,8 @@ setClass("ARFIMApath",
 		contains = "ARFIMA")
 
 setClass("ARFIMAroll",
-		representation(roll = "vector",
-				forecast = "vector",
-				model = "vector"),
+		representation(model = "vector",
+				forecast = "vector"),
 		contains = "ARFIMA")
 
 
